#include "MainComponent.h"
#include "PluginWindow.h"

MainComponent::MainComponent()
    :editor_button_("Editor", "Open/Close Editor")
{
    editor_button_.setClickingTogglesState(true);
    editor_button_.setColour(juce::TextButton::buttonOnColourId, juce::Colours::blue);
    editor_button_.onClick = [this] 
    {
        SetEditorVisible(editor_button_.getToggleState());
    };

    addAndMakeVisible(editor_button_);
    setSize (800, 400);
}

MainComponent::~MainComponent()
{
}

void MainComponent::paint (juce::Graphics& g)
{
    g.fillAll (getLookAndFeel().findColour (juce::ResizableWindow::backgroundColourId));
    g.setColour(findColour(juce::Label::textColourId));
    g.drawText("This is MainWindow.", getLocalBounds(), juce::Justification::centredTop);
}

void MainComponent::resized()
{
    editor_button_.setCentrePosition(getLocalBounds().getCentre());
    editor_button_.centreWithSize(100, 50);
}

void MainComponent::SetEditorVisible(bool should_be_visible)
{
    if (should_be_visible)
    {
        if(plugin_editor_window_ == nullptr)
            plugin_editor_window_.reset(new PluginEditorWindow(*this));
    }
    else
    {
        plugin_editor_window_ = nullptr;
    }

    if (editor_button_.getToggleState() != should_be_visible)
        editor_button_.setToggleState(should_be_visible, juce::dontSendNotification);
}
